@@ -1,8 +1,14 @@
 """AIOGitHubAPI: objects.base"""
 import logging
+from typing import TYPE_CHECKING
+
+from aiohttp.hdrs import ETAG
 
 from aiogithubapi.common.const import HttpStatusCode
 
+if TYPE_CHECKING:
+    from ..client import AIOGitHubAPIClient
+
 
 class AIOGitHubAPIBase:
     """Base class for AIOGitHubAPI."""
@@ -30,8 +36,13 @@ class AIOGitHubAPIResponse:
         """initialise."""
         self.headers: dict = {}
         self.status: HttpStatusCode = HttpStatusCode.OK
-        self.data: dict or str = {}
+        self.data: dict or str or list = {}
 
     def as_dict(self):
         """Return attributes as a dict."""
         return {"headers": self.headers, "status": self.status, "data": self.data}
+
+    @property
+    def etag(self):
+        """Return the ETag for this response."""
+        return self.headers.get(ETAG)
